"""Common configuration constants
"""

PROJECTNAME = 'cs.pfg.multifile'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'FormMultiFileField': 'cs.pfg.multifile: Add FormMultiFileField',
}
